[Pywps-commits] r1122 - branches/pywps-3.2-soap/pywps/Wps/Execute

scm-commit@wald.intevation.org scm-commit at wald.intevation.org
Wed Feb 9 11:46:08 CET 2011


Author: jesus
Date: 2011-02-09 11:46:06 +0100 (Wed, 09 Feb 2011)
New Revision: 1122

Modified:
   branches/pywps-3.2-soap/pywps/Wps/Execute/__init__.py
Log:
missing bool to str cast in LineageInput

Modified: branches/pywps-3.2-soap/pywps/Wps/Execute/__init__.py
===================================================================
--- branches/pywps-3.2-soap/pywps/Wps/Execute/__init__.py	2011-02-08 17:24:55 UTC (rev 1121)
+++ branches/pywps-3.2-soap/pywps/Wps/Execute/__init__.py	2011-02-09 10:46:06 UTC (rev 1122)
@@ -750,9 +750,9 @@
         self.templateProcessor.set("Inputs",templateInputs)
 
     def _lineageLiteralInput(self, input, wpsInput, literalInput):
         """ Fill input of literal data
         """
-        literalInput["literaldata"] = wpsInput["value"]
+        literalInput["literaldata"] = str(wpsInput["value"])
         literalInput["uom"] = str(input.uom)
         return literalInput
 
@@ -845,6 +845,7 @@
         self.templateProcessor.set("Outputdefinitions",templateOutputs)
 
     def _lineageLiteralOutput(self, output, literalOutput):
+        
         if len(output.uoms):
                 literalOutput["uom"] = str(output.uoms[0])
         return literalOutput
@@ -750,9 +750,9 @@
 
     def _lineageLiteralInput(self, input, wpsInput, literalInput):
-        """ Fill input of literal data
+        """ Fill input of literal data, boolean value will be cast to str
         """



More information about the Pywps-commits mailing list